==============
Module - hiera
==============


This module provides for the following ansible plugin:

    * hiera


.. ansibleautoplugin::
   :module: validations_common/library/hiera.py
   :documentation: true
   :examples: true
